@@ -31,7 +31,7 @@ pub fn log_error<T: Into<String>>(line: T) {
 ///
 /// module for conveniency
 ///
-mod prelude {
+pub mod prelude {
     pub use super::log_error;
     pub use super::log_info;
     pub use super::log_warn;
